summaryrefslogtreecommitdiffstats
path: root/routers/private/key.go
diff options
context:
space:
mode:
Diffstat (limited to 'routers/private/key.go')
-rw-r--r--routers/private/key.go78
1 files changed, 11 insertions, 67 deletions
diff --git a/routers/private/key.go b/routers/private/key.go
index ee22f6ac48..f7212ec892 100644
--- a/routers/private/key.go
+++ b/routers/private/key.go
@@ -12,30 +12,10 @@ import (
macaron "gopkg.in/macaron.v1"
)
-// UpdateDeployKey update deploy key updates
-func UpdateDeployKey(ctx *macaron.Context) {
- repoID := ctx.ParamsInt64(":repoid")
- keyID := ctx.ParamsInt64(":keyid")
- deployKey, err := models.GetDeployKeyByRepo(keyID, repoID)
- if err != nil {
- ctx.JSON(500, map[string]interface{}{
- "err": err.Error(),
- })
- return
- }
- deployKey.UpdatedUnix = util.TimeStampNow()
- if err = models.UpdateDeployKeyCols(deployKey, "updated_unix"); err != nil {
- ctx.JSON(500, map[string]interface{}{
- "err": err.Error(),
- })
- return
- }
- ctx.PlainText(200, []byte("success"))
-}
-
-// UpdatePublicKey update publick key updates
-func UpdatePublicKey(ctx *macaron.Context) {
+// UpdatePublicKeyInRepo update public key and deploy key updates
+func UpdatePublicKeyInRepo(ctx *macaron.Context) {
keyID := ctx.ParamsInt64(":id")
+ repoID := ctx.ParamsInt64(":repoid")
if err := models.UpdatePublicKeyUpdated(keyID); err != nil {
ctx.JSON(500, map[string]interface{}{
"err": err.Error(),
@@ -43,60 +23,24 @@ func UpdatePublicKey(ctx *macaron.Context) {
return
}
- ctx.PlainText(200, []byte("success"))
-}
-
-//GetPublicKeyByID chainload to models.GetPublicKeyByID
-func GetPublicKeyByID(ctx *macaron.Context) {
- keyID := ctx.ParamsInt64(":id")
- key, err := models.GetPublicKeyByID(keyID)
- if err != nil {
- ctx.JSON(500, map[string]interface{}{
- "err": err.Error(),
- })
- return
- }
- ctx.JSON(200, key)
-}
-
-//GetUserByKeyID chainload to models.GetUserByKeyID
-func GetUserByKeyID(ctx *macaron.Context) {
- keyID := ctx.ParamsInt64(":id")
- user, err := models.GetUserByKeyID(keyID)
+ deployKey, err := models.GetDeployKeyByRepo(keyID, repoID)
if err != nil {
+ if models.IsErrDeployKeyNotExist(err) {
+ ctx.PlainText(200, []byte("success"))
+ return
+ }
ctx.JSON(500, map[string]interface{}{
"err": err.Error(),
})
return
}
- ctx.JSON(200, user)
-}
-
-//GetDeployKey chainload to models.GetDeployKey
-func GetDeployKey(ctx *macaron.Context) {
- repoID := ctx.ParamsInt64(":repoid")
- keyID := ctx.ParamsInt64(":keyid")
- dKey, err := models.GetDeployKeyByRepo(keyID, repoID)
- if err != nil {
- if models.IsErrDeployKeyNotExist(err) {
- ctx.JSON(404, []byte("not found"))
- return
- }
+ deployKey.UpdatedUnix = util.TimeStampNow()
+ if err = models.UpdateDeployKeyCols(deployKey, "updated_unix"); err != nil {
ctx.JSON(500, map[string]interface{}{
"err": err.Error(),
})
return
}
- ctx.JSON(200, dKey)
-}
-//HasDeployKey chainload to models.HasDeployKey
-func HasDeployKey(ctx *macaron.Context) {
- repoID := ctx.ParamsInt64(":repoid")
- keyID := ctx.ParamsInt64(":keyid")
- if models.HasDeployKey(keyID, repoID) {
- ctx.PlainText(200, []byte("success"))
- return
- }
- ctx.PlainText(404, []byte("not found"))
+ ctx.PlainText(200, []byte("success"))
}